@@ -1,29 +1,27 @@
 =begin
   gettext/cgi.rb - GetText for CGI
 
-  Copyright (C) 2005  Masao Mutoh
+  Copyright (C) 2005-2009  Masao Mutoh
 
   You may redistribute it and/or modify it under the same
-  license terms as Ruby.
-
-  $Id: cgi.rb,v 1.7 2007/10/29 15:32:39 mutoh Exp $
+  license terms as Ruby or LGPL.
 =end
 
 require 'cgi'
 require 'gettext'
-require 'locale/cgi'
+
+Locale.init(:driver => :cgi)
 
 module GetText
-  module_function
 
-  # Sets a CGI object.
+  # Sets a CGI object. This methods is appeared when requiring "gettext/cgi".
   # * cgi_: CGI object
   # * Returns: self
   def set_cgi(cgi_)
     Locale.set_cgi(cgi_)
   end
 
-  # Same as GetText.set_cgi.
+  # Same as GetText.set_cgi. This methods is appeared when requiring "gettext/cgi".
   # * cgi_: CGI object
   # * Returns: cgi_
   def cgi=(cgi_)
@@ -31,7 +29,7 @@ module GetText
     cgi_
   end
 
-  # Gets the CGI object. If it is nil, returns new CGI object.
+  # Gets the CGI object. If it is nil, returns new CGI object. This methods is appeared when requiring "gettext/cgi".
   # * Returns: the CGI object
   def cgi
     Locale.cgi
