@@ -1,15 +1,16 @@
 #!/usr/bin/ruby
 # hello.rb - sample for _() and class.
 #
-# Copyright (C) 2001-2006 Masao Mutoh
+# Copyright (C) 2001-2009 Masao Mutoh
 # This file is distributed under the same license as Ruby-GetText-Package.
 
+require 'rubygems'
 require 'gettext'
 
 class HelloWorld
   include GetText
 
-  bindtextdomain("hello", "locale")
+  bindtextdomain("hello", :path => "locale")
 
   def hello
     print _("Hello World\n")
@@ -28,8 +29,8 @@ if __FILE__ == $0
   GetText.set_locale_all("en")
   p GetText.locale.to_s
   a.hello # Show in English
-  
+
   # Retrive original locale
-  GetText.set_locale_all(old)
+  GetText.set_locale(old)
   a.hello # Show in your locale
 end
