@@ -2,9 +2,7 @@ require 'gettext'
 
 class TestPGetText
   include GetText
-  def initialize
-    bindtextdomain("test_pgettext", "locale")
-  end
+  bindtextdomain("pgettext", :path => "locale")
 
   def test_1
     p_("AAA", "BBB")
@@ -30,4 +28,9 @@ class TestPGetText
     _("BBB")
   end
 
+  def with_context
+    # TRANSLATORS:please translate 'name' in the context of 'program'.
+    # Hint: the translation should NOT contain the translation of 'program'.
+    p_('program', 'name')
+  end
 end
